@@ -1,7 +1,7 @@
 package PERLANCAR::HTML::Tree::Examples;
 
 our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '1.000'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,8 +70,7 @@ sub gen_sample_html {
         $elems_per_level = ['body', 'h1'..'h4'];
     } elsif ($size eq 'medium1') {
         $nums_per_level = [100, 3000, 5000, 8000, 3000, 1000, 300];
-        $elems_per_level = ['body', 'class', 'class', 'class', 'class',
-                            'table', 'tr', 'td'];
+        $elems_per_level = ['body', 'h1'..'h7'];
     } else {
         die "Unknown size '$size'";
     }
@@ -103,7 +102,7 @@ PERLANCAR::HTML::Tree::Examples - Generate sample HTML document
 
 =head1 VERSION
 
-This document describes version 0.05 of PERLANCAR::HTML::Tree::Examples (from Perl distribution PERLANCAR-HTML-Tree-Examples), released on 2016-04-01.
+This document describes version 1.000 of PERLANCAR::HTML::Tree::Examples (from Perl distribution PERLANCAR-HTML-Tree-Examples), released on 2016-04-01.
 
 =head1 SYNOPSIS
 
